#
# spec file for package nim
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           nim
Version:        0.19.6
Release:        2.3.1
Summary:        A statically typed, imperative programming language
License:        MIT
Group:          Development/Languages/Other
URL:            https://nim-lang.org/
Source0:        https://nim-lang.org/download/nim-%{version}.tar.xz
Source1:        nim-rpmlintrc
Recommends:     git
ExclusiveArch:  %{ix86} x86_64

%description
Nim is a statically typed, imperative programming language.

Beneath a infix/indentation-based syntax with a (AST-based) macro
system lies a semantic model that supports a soft realtime GC on
thread local heaps. Asynchronous message passing is used between
threads. An unsafe shared memory heap is also provided for the
increased efficiency that results from that model.

%prep
%setup -q

%build
export CFLAGS="%{optflags}"
export NIMFLAGS="$(echo '%{optflags}' | sed 's/\([^[:space:]]\+\)/--passC:\1/g')"
export NIMFLAGS="$NIMFLAGS %{?jobs:--parallelBuild:%{jobs}}"

./build.sh

make %{?_smp_mflags} V=1 \
  CFLAGS="%{optflags}"
./bin/nim c $NIMFLAGS koch

./koch boot -d:release $NIMFLAGS \
  -d:useGnuReadline
./koch tools -d:release $NIMFLAGS

%install
./koch install %{buildroot}%{_libdir}

mkdir -p %{buildroot}%{_bindir}/ %{buildroot}%{_sysconfdir}/nim \
  %{buildroot}%{_docdir}/nim/

ls ./bin | while read f; do
    install -Dpm 0755 "./bin/$f" "%{buildroot}%{_libdir}/nim/bin/$f"
    ln -s "%{_libdir}/nim/bin/$f" "%{buildroot}%{_bindir}/$f"
done

mv -T %{buildroot}%{_libdir}/nim/config/ %{buildroot}%{_sysconfdir}/nim/

mv -T %{buildroot}%{_libdir}/nim/doc/ %{buildroot}%{_docdir}/nim/
ln -s %{_docdir}/nim/ %{buildroot}%{_libdir}/nim/doc

%files
%license copying.txt
%doc doc/advopt.txt doc/basicopt.txt
%doc %{_docdir}/nim/
%dir %{_sysconfdir}/nim
%config %{_sysconfdir}/nim/nim*.cfg
%{_bindir}/nim*
%{_libdir}/nim/

%changelog
* Fri May 31 2019 Martin Pluskal <mpluskal@suse.com>
- Force more optflags usage
- Fix location of config files (boo#1137006)
* Tue May 14 2019 m.szczepaniak.000@gmail.com
- Update to version 0.19.6:
  Please see:
  https://nim-lang.org/blog/2019/05/13/version-0196-released.html
* Tue Jan  1 2019 mvetter@suse.com
- Update to version 0.19.2:
  Please see:
  https://nim-lang.org/blog/2018/12/31/version-0192-released.html
* Mon Oct 22 2018 mvetter@suse.com
- Update to version 0.19.0:
  * Please see:
    https://nim-lang.org/blog/2018/09/26/version-0190-released.html
* Fri Mar  2 2018 mvetter@suse.com
- Update to version 0.18.0:
  * Please see:
    https://nim-lang.org/blog/2018/03/01/version-0180-released.html
- Add nim-rpmlintrc
* Fri Jan  5 2018 mpluskal@suse.com
- Update to version 0.17.2:
  * Bugfix release
  * For details see:
    https://nim-lang.org/blog/2017/09/07/version-0172-released.html
* Sat Jun  3 2017 mpluskal@suse.com
- Update to version 0.17.0:
  * https://nim-lang.org/blog/2017/05/17/version-0170-released.html
* Sat Mar 11 2017 mpluskal@suse.com
- Update list of files to fix building on Factory
* Thu Mar  2 2017 jengelh@inai.de
- Update description
* Sun Feb 19 2017 sor.alexei@meowr.ru
- Update to version 0.16.0:
  * No changelog available.
- Build and install libraries, etc.
- Install configuration files.
- Recommend git for nimble.
* Fri Dec 23 2016 mpluskal@suse.com
- Cleanup package to follow packaging guidelines
* Fri Dec 23 2016 thomazi@linux.com
- Fixing spec summary
